@@ -1,9 +1,12 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
+. $(dirname "${BASH_SOURCE[0]}")/common.sh
 packname="0-init-fail-pack"
 deps="logger PACKAGE_DONT_EXIST" # would be very unlucky if it does exist...
 
-$DUB init -n $packname $deps
+if $DUB init -n $packname $deps 2>/dev/null; then
+    die $LINENO 'Init with unknown non-existing dependency expected to fail'
+fi
 
 function cleanup {
     rm -rf $packname
@@ -11,6 +14,5 @@ function cleanup {
 
 if [ -e $packname/dub.sdl ]; then # package is there, it should have failed
     cleanup
-    exit 1
+    die $LINENO "$packname/dub.sdl was not created"
 fi
-exit 0
