@@ -13,7 +13,7 @@ function cleanup {
 trap cleanup EXIT
 
 if ! $DUB describe --compiler=$DC --import-paths > "$temp_file"; then
-    die 'Printing import paths failed!'
+    die $LINENO 'Printing import paths failed!'
 fi
 
 # Create the expected output path file to compare against.
@@ -23,6 +23,6 @@ echo "$CURR_DIR/describe-dependency-2/some-path/" >> "$CURR_DIR/expected-import-
 echo "$CURR_DIR/describe-dependency-3/dep3-source/" >> "$CURR_DIR/expected-import-path-output"
 
 if ! diff "$CURR_DIR"/expected-import-path-output "$temp_file"; then
-    die 'The import paths did not match the expected output!'
+    die $LINENO 'The import paths did not match the expected output!'
 fi
 
