@@ -1,9 +1,10 @@
-#!/bin/sh
+#!/usr/bin/env bash
 
+. $(dirname "${BASH_SOURCE[0]}")/common.sh
 cd ${CURR_DIR}/issue934-path-dep
 rm -rf main/.dub
 rm -rf a/.dub
 rm -rf b/.dub
 rm -f main/dub.selections.json
 cd main
-${DUB} build --compiler=${DC} || exit 1
+${DUB} build --compiler=${DC}
