@@ -39,14 +39,6 @@ FRONTEND="${FRONTEND:-}"
 
 if [ "$#" -gt 0 ]; then FILTER=$1; else FILTER=".*"; fi
 
-for script in $(ls $CURR_DIR/*.sh); do
-    if [[ ! "$script" =~ $FILTER ]]; then continue; fi
-    if [ "$script" = "$(gnureadlink ${BASH_SOURCE[0]})" ] || [ "$(basename $script)" = "common.sh" ]; then continue; fi
-    if [ -e $script.min_frontend ] && [ ! -z "$FRONTEND" ] && [ ${FRONTEND} \< $(cat $script.min_frontend) ]; then continue; fi
-    log "Running $script..."
-    DUB=$DUB DC=$DC CURR_DIR="$CURR_DIR" $script || logError "Script failure."
-done
-
 for pack in $(ls -d $CURR_DIR/*/); do
     if [[ ! "$pack" =~ $FILTER ]]; then continue; fi
     if [ -e $pack/.min_frontend ] && [ ! -z "$FRONTEND" -a "$FRONTEND" \< $(cat $pack/.min_frontend) ]; then continue; fi
